# NovelSave Sources

A collection of novel sources offering varying amounts of scraping capability.

> Request a new source by [creating a new issue](https://github.com/mHaisham/novelsave_sources/issues/new/choose)

## Sources

### Novel

| Sources                               | Search | Last Checked |
| ------------------------------------- | :----: | :--: |
| https://www.webnovel.com              |        | 2021-08-25 |
| https://www.wuxiaworld.co             |        |  |
| https://www.boxnovel.co               |        |  |
| https://www.readlightnovel.org        |        |  |
| https://insanitycave.poetry.blog      |        |  |
| https://ktlchamber.wordpress.com      |        |  |
| https://kieshitl.wordpress.com        |        |  |
| https://www.scribblehub.com           |        | 2021-08-17 |
| https://www.mtlnovel.com              |        |  |
| https://novelfull.com                 |        |  |
| https://www.wuxiaworld.com            |        |  |
| https://www.royalroad.com             |        | 2021-08-17 |
| https://www.wattpad.com               |        |  |
| https://forums.spacebattles.com       |        |  |
| https://forums.sufficientvelocity.com |        |  |
| https://dragontea.ink                 |        | 2021-08-20 |
| https://novelsite.net                 |        |  |
| https://foxaholic.com                 |        |  |
| https://chrysanthemumgarden.com       |        | 2021-08-24 |
| https://peachpitting.com              |        |  |
| https://betwixtedbutterfly.com        |        |  |
| https://dummynovels.com               |        |  |
| https://www.chickengege.org           |        |  |
| https://wuxiaworld.online             |        |  |
| https://novelonlinefull.com           |        |  |
| https://www.novelpassion.com          |        |  |
| https://novelfun.net                  |        |  |
| https://www.novelhall.com             |        |  |
| https://novelsrock.com                |        |  |
| https://creativenovels.com            |        | 2021-08-20 |
| https://wuxiaworld.site               |        |  |
| https://novelgate.net                 |        | 2021-08-26 |
| https://rainofsnow.com                |        | 2021-08-16 |

#### Rejected

| Sources                                   | Reason                    |
| ----------------------------------------- | ------------------------- |
| https://www.fanfiction.net                | Cloudflare bot protection |

### Metadata

| Metadata Source              | Last Checked |
| ---------------------------- | :----------: |
| https://www.wlnupdates.com   | 2021-08-25   |
| https://www.novelupdates.com |  |

## Disclaimer

We are not affiliated, associated, authorized, endorsed by, or in any way officially
connected with any of the [sources](#sources) mentioned above.

## License

[Apache-2.0](https://github.com/mHaisham/novelsave_sources/blob/master/LICENSE)